@@ -6,14 +6,17 @@ class ComboBox(QComboBox):
     clicked = pyqtSignal()
     def __init__(self):
         QComboBox.__init__(self)
-        self.setView(QListView())
+        listView = QListView()
+        self.setView(listView)
         return
 
     def __del__(self):
         return
 
     def mouseReleaseEvent(self, QMouseEvent):
+        self.showPopup()
+
+    def mousePressEvent(self, QMouseEvent):
         self.clicked.emit()
-        return
 
 
